*************************************************************************************************
*** This do file creates the regression analysis for 
*** STATE CONTROL AND THE EFFECTS OF FOREIGN RELATIONS ON BILATERAL TRADE
*** Christina Davis (Princeton University)
*** Andreas Fuchs (Heidelberg University)
*** Kristina Johnson (University of Massachusetts)
*** Published in: Journal of Conflict Resolution
*************************************************************************************************

set more off
set matsize 1000


*cd "C:\Users\a.fuchs\Dropbox\Forschung\B State control\STATE CONTROL\data\data processed"


* Install additional ado files
adopath ++ "ado"
sysdir set PLUS "ado"
net install estout, replace from(http://fmwww.bc.edu/RePEc/bocode/e)
net install outreg2, replace from(http://fmwww.bc.edu/RePEc/bocode/o)

* Create folder "JCR" to store results
program define confirmdir, rclass
 	local cwd `"`c(pwd)'"'
	quietly capture cd `"`1'"'
	local confirmdir=_rc 
	quietly cd `"`cwd'"'
	return local confirmdir `"`confirmdir'"'
end 
	confirmdir `"jcr"'	  /* does folder "jcr" exist? */
		if `r(confirmdir)'!=0  {  /* folder does not yet exist */
			mkdir "jcr"  /* makes the folder  */
					      } 
	      else {
			di "folder jcr already exists"
			}
program drop confirmdir


* Open log file
cap log close
log using "jcr\DFJ_JCR_replication", replace



*******************************************************************************************************************
************* Define macros, label variables for regression tables, compute correlations
*******************************************************************************************************************

* Specify variables of interest
local relations "GDELTn_gov_ln1 GDELTn_mil_ln1 ipdistance_ln1" // variables of interests

* Specify control variables
local controls1 "distw_ln gdp_con_ln1 population_ln1 contig comlang_ethno landlocked wto1 polity21 atop_ally_usa1" // controls for specifications without country-FE
local controls2 "gdp_con_ln1 population_ln1 wto1 polity21" // controls for specifications with country-FE


use "dataset_DFJ_replication.dta", clear

* Redo the labels for short version
label var distw_ln "(log) Distance"
label var gdp_con_ln1 "(log) GDP"
label var population_ln1 "(log) Population"
label var contig "Neighbor"
label var comlang_ethno "Common language"
label var landlocked "Landlocked"
label var wto1 "WTO member"
label var polity21 "Polity"
label var atop_ally_usa1 "US ally"
label var GDELTn_gov_ln1 "(log) Political relations"
label var GDELTn_mil_ln1 "(log) Political relations"
label var ipdistance_ln1 "(log) Political relations"
label var oil_state "Oil states"

* Correlations in footnote X on p. X 
pwcorr GDELTn GDELTn_gov GDELTn_mil GNCUM
pwcorr GDELTn_ln1 GDELTn_gov_ln1 GDELTn_mil_ln1 GNCUM_ln1

save "dataset_DFJ_replication2.dta", replace



*******************************************************************************************************************
************* Table 1: Bad relations
*******************************************************************************************************************

use "table1.dta", clear
outsheet country if code1=="CHN" & rel=="GDELTn_gov" & rank<11 using "jcr\table1_chn_gov.xls", replace
outsheet country if code1=="CHN" & rel=="GDELTn_mil" & rank<11 using "jcr\table1_chn_mil.xls", replace
outsheet country if code1=="CHN" & rel=="ipdistance" & rank<11 using "jcr\table1_chn_ipd.xls", replace
outsheet country if code1=="IND" & rel=="GDELTn_gov" & rank<11 using "jcr\table1_ind_gov.xls", replace
outsheet country if code1=="IND" & rel=="GDELTn_mil" & rank<11 using "jcr\table1_ind_mil.xls", replace
outsheet country if code1=="IND" & rel=="ipdistance" & rank<11 using "jcr\table1_ind_ipd.xls", replace



*******************************************************************************************************************
************* Table 2: Imports to China
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="CHN"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations {
cap drop rel
ren `rel' rel

reg imports_soe_con_LN rel `controls2' dyear* dcou* if year>=1993 & year<=2012
est store soe

reg imports_pri_con_LN rel `controls2' dyear* dcou* if year>=1993 & year<=2012
est store nonsoe

suest soe nonsoe, cluster(codeid)
est store c_`rel'
test [soe_mean]rel=[nonsoe_mean]rel
estadd scalar waldp=r(p)
}
estout c_* using "jcr\table2.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_* using "jcr\table2.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estimates drop _all



*******************************************************************************************************************
************* Table 3: Imports to India
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="IND"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations`cc1' {
cap drop rel
ren `rel' rel

reg imports_soe_con_LN rel `controls2' dyear* dcou* if year>=1991 & year<=2012
est store soe

reg imports_pri_con_LN rel `controls2' dyear* dcou* if year>=1991 & year<=2012
est store nonsoe

suest soe nonsoe, cluster(codeid)
est store c_`rel'
test [soe_mean]rel=[nonsoe_mean]rel
estadd scalar waldp=r(p)
}
estout c_* using "jcr\table3.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_* using "jcr\table3.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing


estimates drop _all



*******************************************************************************************************************
************* Table 4: Imports to China, India, South Africa, and the United States
*******************************************************************************************************************

*CHN
use "dataset_DFJ_replication2.dta", clear

keep if code1=="CHN"

encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

label var GDELTn_gov_ln1 "(log) Negative events (government)"
label var GDELTn_mil_ln1 "(log) Negative events (military)"
label var ipdistance_ln1 "(log) UNGA voting (ideal point distance)"

reg imports_con_LN GDELTn_gov_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store CHN1
reg imports_con_LN GDELTn_mil_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store CHN2
reg imports_con_LN ipdistance_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store CHN3


*IND
use "dataset_DFJ_replication2.dta", clear

keep if code1=="IND"

encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

label var GDELTn_gov_ln1 "(log) Negative events (government)"
label var GDELTn_mil_ln1 "(log) Negative events (military)"
label var ipdistance_ln1 "(log) UNGA voting (ideal point distance)"

reg imports_con_LN GDELTn_gov_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store IND1
reg imports_con_LN GDELTn_mil_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store IND2
reg imports_con_LN ipdistance_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store IND3


*USA
use "dataset_DFJ_replication2.dta", clear

keep if code1=="CHN" // USA data stored under this code1

encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

drop GDELTn_gov_ln1 GDELTn_mil_ln1 ipdistance_ln1
ren XGDELTn_gov_ln1 GDELTn_gov_ln1
ren XGDELTn_mil_ln1 GDELTn_mil_ln1
ren Xipdistance_ln1 ipdistance_ln1

label var GDELTn_gov_ln1 "(log) Negative events (government)"
label var GDELTn_mil_ln1 "(log) Negative events (military)"
label var ipdistance_ln1 "(log) UNGA voting (ideal point distance)"

reg imports_usazaf_con_LN GDELTn_gov_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store USA1
reg imports_usazaf_con_LN GDELTn_mil_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store USA2
reg imports_usazaf_con_LN ipdistance_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store USA3


*ZAF
use "dataset_DFJ_replication2.dta", clear

keep if code1=="IND" // ZAF data stored under this code1

encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

drop GDELTn_gov_ln1 GDELTn_mil_ln1 ipdistance_ln1
ren XGDELTn_gov_ln1 GDELTn_gov_ln1
ren XGDELTn_mil_ln1 GDELTn_mil_ln1
ren Xipdistance_ln1 ipdistance_ln1

label var GDELTn_gov_ln1 "(log) Negative events (government)"
label var GDELTn_mil_ln1 "(log) Negative events (military)"
label var ipdistance_ln1 "(log) UNGA voting (ideal point distance)"

reg imports_usazaf_con_LN GDELTn_gov_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store ZAF1
reg imports_usazaf_con_LN GDELTn_mil_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store ZAF2
reg imports_usazaf_con_LN ipdistance_ln1 `controls2' dyear* dcou* if year>=1993 & year<=2012, cluster(codeid)
est store ZAF3

estout CHN1 IND1 ZAF1 USA1 using "jcr\table4_row1.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy*, relax)
	
estout CHN2 IND2 ZAF2 USA2 using "jcr\table4_row2.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy*, relax)
	
estout CHN3 IND3 ZAF3 USA3 using "jcr\table4_row3.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy*, relax)
	


*******************************************************************************************************************
************* Table 5: Exports from China
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="CHN"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations {
cap drop rel
ren `rel' rel

reg exports_soe_con_LN rel `controls2' dyear* dcou* if year>=1993 & year<=2012
est store soe

reg exports_pri_con_LN rel `controls2' dyear* dcou* if year>=1993 & year<=2012
est store nonsoe

suest soe nonsoe, cluster(codeid)
est store c_`rel'
test [soe_mean]rel=[nonsoe_mean]rel
estadd scalar waldp=r(p)
}
estout c_* using "jcr\table5.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_* using "jcr\table5.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing


estimates drop _all



*******************************************************************************************************************
************* Table 6: Exports from India
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="IND"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations {
cap drop rel
ren `rel' rel

reg exports_soe_con_LN rel `controls2' dyear* dcou* if year>=1991 & year<=2012
est store soe

reg exports_pri_con_LN rel `controls2' dyear* dcou* if year>=1991 & year<=2012
est store nonsoe

suest soe nonsoe, cluster(codeid)
est store c_`rel'
test [soe_mean]rel=[nonsoe_mean]rel
estadd scalar waldp=r(p)
}
estout c_* using "jcr\table6.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_* using "jcr\table6.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp, ///
	labels("Number of observations" "Wald test (p-value)") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estimates drop _all



*******************************************************************************************************************
************* Table 8: Descriptive Statistics
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear
sum imports_soe_con_LN imports_pri_con_LN exports_soe_con_LN exports_pri_con_LN `relations' `controls1' if year>=1991 & year<=2012

estpost sum imports_soe_con_LN imports_pri_con_LN exports_soe_con_LN exports_pri_con_LN `relations' `controls1' if year>=1991 & year<=2012
estout using "jcr\table8.txt", replace cells ("count mean sd min max")



*******************************************************************************************************************
************* Table 9: Imports to China and oil states
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="CHN"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)


foreach rel of local relations {
cap drop rel
ren `rel' rel

reg imports_soe_con_LN c.rel#0.oil_state c.rel#1.oil_state `controls2' dyear* dcou* if year>=1993 & year<=2012
est store soe

reg imports_pri_con_LN c.rel#0.oil_state c.rel#1.oil_state `controls2' dyear* dcou* if year>=1993 & year<=2012
est store nonsoe

suest soe nonsoe, cluster(codeid)
est store c_`rel'
test [soe_mean]c.rel#0.oil_state=[nonsoe_mean]c.rel#0.oil_state
estadd scalar waldp_nonoil=r(p)
test [soe_mean]c.rel#1.oil_state=[nonsoe_mean]c.rel#1.oil_state
estadd scalar waldp_oil=r(p)
}

estout c_* using "jcr\table9.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp_nonoil waldp_oil, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_* using "jcr\table9.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp_nonoil waldp_oil, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing


estimates drop _all



*******************************************************************************************************************
************* Table 10: Imports to India and oil states
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="IND"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations {
cap drop rel
cap ren `rel' rel

reg imports_soe_con_LN c.rel#0.oil_state c.rel#1.oil_state `controls2' dyear* dcou* if year>=1991 & year<=2012
est store soe

reg imports_pri_con_LN c.rel#0.oil_state c.rel#1.oil_state `controls2' dyear* dcou* if year>=1991 & year<=2012
est store nonsoe

suest soe nonsoe, cluster(codeid)
est store c_`rel'

test [soe_mean]c.rel#0.oil_state=[nonsoe_mean]c.rel#0.oil_state
estadd scalar waldp_nonoil=r(p)
test [soe_mean]c.rel#1.oil_state=[nonsoe_mean]c.rel#1.oil_state
estadd scalar waldp_oil=r(p)
}

estout c_* using "jcr\table10.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp_nonoil waldp_oil, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output

estout c_* using "jcr\table10.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N waldp_nonoil waldp_oil, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output

estimates drop _all



*******************************************************************************************************************
************* Table 11: Imports to China (random-effects model)
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="CHN"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations {
cap drop rel
ren `rel' rel

xtreg imports_soe_con_LN rel `controls1' dyear* if year>=1993 & year<=2012, re cluster(codeid)
est store c_soe`rel'

xtreg imports_pri_con_LN rel `controls1' dyear* if year>=1993 & year<=2012, re cluster(codeid)
est store c_nonsoe`rel'
}
estout c_soe* using "jcr\table11soe.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_soe* using "jcr\table11soe.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing


estout c_nonsoe* using "jcr\table11nonsoe.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_nonsoe* using "jcr\table11nonsoe.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing


estimates drop _all



*******************************************************************************************************************
************* Table 12: Imports to India (random-effects model)
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

keep if code1=="IND"
encode code, gen(codeid)
tsset codeid year
tab year, gen(dyear)
tab code, gen(dcou)

foreach rel of local relations`cc1' {
cap drop rel
ren `rel' rel

xtreg imports_soe_con_LN rel `controls1' dyear* if year>=1991 & year<=2012, re cluster(codeid)
est store c_soe`rel'

xtreg imports_pri_con_LN rel `controls1' dyear* if year>=1991 & year<=2012, re cluster(codeid)
est store c_nonsoe`rel'

}
estout c_soe* using "jcr\table12soe.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_soe* using "jcr\table12soe.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_nonsoe* using "jcr\table12nonsoe.txt", replace label delimiter(_tab) noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing

estout c_nonsoe* using "jcr\table12nonsoe.tex", replace label noabbrev				///
	cells(b(star fmt(%9.4f)) se(par fmt(4))) style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, ///
	labels("Number of observations") ///
	fmt(0 3)) drop(o.* dc* dy* _cons, relax)
*labels for the table output, keeping for relations and controls, dropping dummies, and telling stata to relax when missing



*******************************************************************************************************************
************* Figure 1: Trade by enterprise ownership type
*******************************************************************************************************************

use "dataset_DFJ_replication2.dta", clear

sort code1 year, stable
collapse (sum) imports*, by(code1 year)
keep if year>=1991 & year<=2011

keep year code1 imports_con imports_soe_con imports_pri_con
reshape wide imports_con imports_soe_con imports_pri_con, i(year) j(code1) string

foreach var of varlist imports_conCHN imports_soe_conCHN imports_pri_conCHN imports_conIND imports_soe_conIND imports_pri_conIND {
replace `var'=`var'/1000000000
}

label var imports_soe_conCHN "Imports via SOEs"
label var imports_pri_conCHN "Imports via PEs"
label var imports_soe_conIND "Imports via SOEs"
label var imports_pri_conIND "Imports via PEs"

gen Simports_soe_conCHN=imports_soe_conCHN/imports_conCHN*100
gen Simports_pri_conCHN=imports_pri_conCHN/imports_conCHN*100

gen Simports_soe_conIND=imports_soe_conIND/imports_conIND*100
gen Simports_pri_conIND=imports_pri_conIND/imports_conIND*100

label var Simports_soe_conCHN "Imports SOEs"
label var Simports_pri_conCHN "Imports PEs"
label var Simports_soe_conIND "Imports SOEs"
label var Simports_pri_conIND "Imports PEs"

twoway line Simports_soe_conCHN Simports_pri_conCHN year, saving(SCHN_imports, replace) title("China") ylabel(0(10)100) scheme(s1mono) lpattern(solid dash) ytitle("Share in total imports (in %)")
twoway line Simports_soe_conIND Simports_pri_conIND year, saving(SIND_imports, replace) title("India") ylabel(0(10)100) scheme(s1mono) lpattern(solid dash)

graph combine SCHN_imports.gph SIND_imports.gph, altshrink scheme(s1mono)
graph export "jcr\figure1.eps", replace
graph export "jcr\figure1.pdf", replace as(pdf)



*******************************************************************************************************************
************* Figure 2: Measures of political relations
*******************************************************************************************************************

* Graphical analysis for China (1990-2011)
foreach var of newlist USA JPN RUS {

use "figure2.dta", clear

keep if code1=="CHN"
keep if code=="`var'"

twoway (line GDELTn_gov year if year>=1990 & year<=2011), name(CHN_`var'_GDELTn_gov, replace) scheme(s1color) nodraw ylabel(0 (1) 5, grid) xlabel(1990 (5) 2010, grid) /*yscale(reverse)*/ title("`var'") ytitle("") xtitle("")
twoway (line GDELTn_mil year if year>=1990 & year<=2011), name(CHN_`var'_GDELTn_mil, replace) scheme(s1color) nodraw ylabel(0 (0.2) 1, grid) xlabel(1990 (5) 2010, grid) /*yscale(reverse)*/ title("`var'") ytitle("") xtitle("")
twoway (line ipdistance year if year>=1990 & year<=2011), name(CHN_`var'_ipdistance, replace) scheme(s1color) nodraw ylabel(0 (1) 5, grid) xlabel(1990 (5) 2010, grid) title("`var'") ytitle("") xtitle("")
}


foreach var of newlist JPN RUS {

use "figure2.dta", clear

keep if code1=="CHN"
keep if code=="`var'"

twoway (line GDELTn_gov year if year>=1990 & year<=2011), name(CHN_`var'_GDELTn_gov, replace) scheme(s1color) nodraw ylabel(0 (0.1) 0.5, grid) xlabel(1990 (5) 2010, grid) /*yscale(reverse)*/ title("`var'") ytitle("") xtitle("")
}

graph combine CHN_USA_GDELTn_gov CHN_JPN_GDELTn_gov CHN_RUS_GDELTn_gov, subtitle("China: GDELT negative events (government actor involved; in 1,000)") name(CHN_GDELTn_gov, replace) scheme(s1color) rows(1) commonscheme altshrink

graph combine CHN_USA_GDELTn_mil CHN_JPN_GDELTn_mil CHN_RUS_GDELTn_mil, subtitle("China: GDELT negative events (military actor involved; in 1,000)") name(CHN_GDELTn_mil, replace) scheme(s1color) rows(1) commonscheme altshrink

graph combine CHN_USA_ipdistance CHN_JPN_ipdistance CHN_RUS_ipdistance, subtitle("China: UN voting alignment (ideal point distance)") name(CHN_ipdistance, replace) scheme(s1color) rows(1) commonscheme altshrink

keep year code1 code GDELTn_gov GDELTn_mil ipdistance
keep if year>=1990 & year<=2011


* Graphical analysis for India (1990-2011)
foreach var of newlist USA JPN RUS {

use "figure2.dta", clear

keep if code1=="IND"
keep if code=="`var'"

twoway (line GDELTn_gov year if year>=1990 & year<=2011), name(IND_`var'_GDELTn_gov, replace) scheme(s1color) nodraw ylabel(0 (0.3) 1.5, grid) xlabel(1990 (5) 2010, grid) /*yscale(reverse)*/ title("`var'") ytitle("") xtitle("")
twoway (line GDELTn_mil year if year>=1990 & year<=2011), name(IND_`var'_GDELTn_mil, replace) scheme(s1color) nodraw ylabel(0 (0.02) 0.1, grid) xlabel(1990 (5) 2010, grid) /*yscale(reverse)*/ title("`var'") ytitle("") xtitle("")
twoway (line ipdistance year if year>=1990 & year<=2011), name(IND_`var'_ipdistance, replace) scheme(s1color) nodraw ylabel(0 (1) 5, grid) xlabel(1990 (5) 2010, grid) title("`var'") ytitle("") xtitle("")
}

foreach var of newlist JPN RUS {

use "figure2.dta", clear

keep if code1=="IND"
keep if code=="`var'"

twoway (line GDELTn_gov year if year>=1990 & year<=2011), name(IND_`var'_GDELTn_gov, replace) scheme(s1color) nodraw ylabel(0 (0.02) 0.1, grid) xlabel(1990 (5) 2010, grid) /*yscale(reverse)*/ title("`var'") ytitle("") xtitle("")
}

graph combine IND_USA_GDELTn_gov IND_JPN_GDELTn_gov IND_RUS_GDELTn_gov, subtitle("India: GDELT negative events (government actor involved; in 1,000)") name(IND_GDELTn_gov, replace) scheme(s1color) rows(1) commonscheme altshrink

graph combine IND_USA_GDELTn_mil IND_JPN_GDELTn_mil IND_RUS_GDELTn_mil, subtitle("India: GDELT negative events (military actor involved; in 1,000)") name(IND_GDELTn_mil, replace) scheme(s1color) rows(1) commonscheme altshrink

graph combine IND_USA_ipdistance IND_JPN_ipdistance IND_RUS_ipdistance, subtitle("India: UN voting alignment (ideal point distance)") name(IND_ipdistance, replace) scheme(s1color) rows(1) commonscheme altshrink

keep year code1 code GDELTn_gov GDELTn_mil ipdistance
keep if year>=1990 & year<=2011


* Create final graph
graph combine CHN_GDELTn_gov IND_GDELTn_gov CHN_GDELTn_mil IND_GDELTn_mil CHN_ipdistance IND_ipdistance, scheme(s1color) cols(1) commonscheme xsize(6) ysize(8) iscale(2) altshrink
graph save "jcr\figure2", replace
graph export "jcr\figure2.pdf", as(pdf) replace
graph export "jcr\figure2.eps", as(eps) replace




log close
